@@ -8,10 +8,11 @@ use solana_account_decoder::UiAccount;
 use solana_client::{
     rpc_client::RpcClient,
     rpc_config::{RpcAccountInfoConfig, RpcSignatureSubscribeConfig},
-    rpc_response::{Response as RpcResponse, RpcSignatureResult, SlotUpdate},
+    rpc_response::{Response, RpcSignatureResult, SlotUpdate},
     tpu_client::{TpuClient, TpuClientConfig},
 };
-use solana_core::{rpc_pubsub::gen_client::Client as PubsubClient, test_validator::TestValidator};
+use solana_core::test_validator::TestValidator;
+use solana_rpc::rpc_pubsub::gen_client::Client as PubsubClient;
 use solana_sdk::{
     commitment_config::CommitmentConfig,
     hash::Hash,
@@ -20,6 +21,7 @@ use solana_sdk::{
     system_transaction,
     transaction::Transaction,
 };
+use solana_transaction_status::TransactionStatus;
 use std::{
     collections::HashSet,
     net::UdpSocket,
@@ -27,7 +29,7 @@ use std::{
     thread::sleep,
     time::{Duration, Instant},
 };
-use tokio::runtime::Runtime;
+use tokio_02::runtime::Runtime;
 
 macro_rules! json_req {
     ($method: expr, $params: expr) => {{
@@ -81,20 +83,24 @@ fn test_rpc_send_tx() {
 
     let mut confirmed_tx = false;
 
-    let request = json_req!("confirmTransaction", [signature]);
+    let request = json_req!("getSignatureStatuses", [[signature]]);
 
     for _ in 0..solana_sdk::clock::DEFAULT_TICKS_PER_SLOT {
         let json = post_rpc(request.clone(), &rpc_url);
 
-        if true == json["result"]["value"] {
-            confirmed_tx = true;
-            break;
+        let result: Option<TransactionStatus> =
+            serde_json::from_value(json["result"]["value"][0].clone()).unwrap();
+        if let Some(result) = result.as_ref() {
+            if result.err.is_none() {
+                confirmed_tx = true;
+                break;
+            }
         }
 
         sleep(Duration::from_millis(500));
     }
 
-    assert_eq!(confirmed_tx, true);
+    assert!(confirmed_tx);
 
     use solana_account_decoder::UiAccountEncoding;
     use solana_client::rpc_config::RpcAccountInfoConfig;
@@ -159,7 +165,7 @@ fn test_rpc_slot_updates() {
         let connect = ws::try_connect::<PubsubClient>(&rpc_pubsub_url).unwrap();
         let client = connect.await.unwrap();
 
-        tokio::spawn(async move {
+        tokio_02::spawn(async move {
             let mut update_sub = client.slots_updates_subscribe().unwrap();
             loop {
                 let response = update_sub.next().await.unwrap();
@@ -243,9 +249,9 @@ fn test_rpc_subscriptions() {
     // Track when subscriptions are ready
     let (ready_sender, ready_receiver) = channel::<()>();
     // Track account notifications are received
-    let (account_sender, account_receiver) = channel::<RpcResponse<UiAccount>>();
+    let (account_sender, account_receiver) = channel::<Response<UiAccount>>();
     // Track when status notifications are received
-    let (status_sender, status_receiver) = channel::<(String, RpcResponse<RpcSignatureResult>)>();
+    let (status_sender, status_receiver) = channel::<(String, Response<RpcSignatureResult>)>();
 
     // Create the pub sub runtime
     let rt = Runtime::new().unwrap();
@@ -268,7 +274,7 @@ fn test_rpc_subscriptions() {
                 )
                 .unwrap_or_else(|err| panic!("sig sub err: {:#?}", err));
 
-            tokio::spawn(async move {
+            tokio_02::spawn(async move {
                 let response = sig_sub.next().await.unwrap();
                 status_sender
                     .send((sig.clone(), response.unwrap()))
@@ -288,7 +294,7 @@ fn test_rpc_subscriptions() {
                     }),
                 )
                 .unwrap_or_else(|err| panic!("acct sub err: {:#?}", err));
-            tokio::spawn(async move {
+            tokio_02::spawn(async move {
                 let response = client_sub.next().await.unwrap();
                 account_sender.send(response.unwrap()).unwrap();
             });
@@ -298,7 +304,7 @@ fn test_rpc_subscriptions() {
         let mut slot_sub = client
             .slot_subscribe()
             .unwrap_or_else(|err| panic!("sig sub err: {:#?}", err));
-        tokio::spawn(async move {
+        tokio_02::spawn(async move {
             let _response = slot_sub.next().await.unwrap();
             ready_sender.send(()).unwrap();
         });
